.. _get-gff-info:

get-gff-info - Extract informations to GFF annotations
======================================================

Overview
--------

.. automodule:: mgkit.workflow.extract_gff_info


Options
-------

.. click:: mgkit.workflow.extract_gff_info:main
   :prog: get-gff-info
   :show-nested:
